Package: crone
Type: Package
Title: Structural Crystallography in 1d
Version: 0.1.1
Date: 2019-08-25
Authors@R: person("James","Foadi",email="j.foadi@bath.ac.uk",role=c("cre","aut"))
Description: Functions to carry out the most important crystallographic calculations for crystal 
             structures made of 1d Gaussian-shaped atoms, especially useful for methods development.
             Main reference: E. Smith, G. Evans, J. Foadi (2017) <doi:10.1088/1361-6404/aa8188>.
License: GPL-2
LazyLoad: yes
LazyData: true
RoxygenNote: 6.1.1
Suggests: knitr
VignetteBuilder: knitr
Encoding: UTF-8
Depends: R (>= 3.5.0)
NeedsCompilation: no
Packaged: 2019-08-24 14:15:46 UTC; james
Author: James Foadi [cre, aut]
Maintainer: James Foadi <j.foadi@bath.ac.uk>
Repository: CRAN
Date/Publication: 2019-08-24 14:40:04 UTC
Built: R 4.6.0; ; 2026-04-26 15:36:42 UTC; unix
