# Generated by roxygen2: do not edit by hand

export(atom_gauss)
export(choose_a)
export(diffraction)
export(erf)
export(expand_to_cell)
export(fluorescent_scan)
export(fousynth)
export(heaviside)
export(invfousynth)
export(kgauss)
export(load_anomalous_data)
export(load_data)
export(load_structure)
export(local_maxima)
export(plot_absorption_curves)
export(read_h)
export(read_x)
export(reduce_to_asu)
export(scafac)
export(sfobs)
export(standardise_fdata)
export(standardise_sdata)
export(structure_gauss)
export(strufac)
export(write_h)
export(write_x)
import(graphics)
import(stats)
import(utils)
